# default settings used for the package builds

NEONDIR := /opt/project-neon

dh_defaults := --parallel --list-missing

cmake_defaults := -DCMAKE_INSTALL_PREFIX=$(NEONDIR) \
		-DCMAKE_PREFIX_PATH=$(NEONDIR) \
		-DKDE_DEFAULT_HOME=.project-neon-kde \
		-DCMAKE_BUILD_TYPE=debugfull \
		-DKDE4_BUILD_TESTS=FALSE


# get version of dpkg we're building with
DPKG_VERSION := $(shell dpkg-query -W -f='$${Version}' dpkg)

# DEPRECATED
dpkg_version := $(DPKG_VERSION)

# define the release we're building on
BUILD_RELEASE := $(shell lsb_release -c | cut -f 2)

# compat level the package is using
COMPAT := $(shell cat debian/compat)

# get the dbg package name from the control file
DEBUG_NAME := $(shell grep "^Package:.*dbg\$$" debian/control | awk '{print $$2}')

# DEPRECATED
dbgpackagename := $(DEBUG_NAME)

# same for the source and binary name
SOURCE_NAME := $(shell head -n 1 debian/control | awk '{print $$2}')
BINARY_NAME := $(shell grep "^Package:.*\$$" debian/control | head -n 1 | awk '{print $$2}')

SCRIPT_DIR := $(NEONDIR)/share/pkg-project-neon/scripts

DEB_HOST_MULTIARCH ?= $(shell dpkg-architecture -qDEB_HOST_MULTIARCH)

# environment setup
export NEONDIR
export PATH := $(NEONDIR)/bin:$(PATH)
export LD_LIBRARY_PATH := $(NEONDIR)/lib:$(NEONDIR)/lib/$(DEB_HOST_MULTIARCH):$(LD_LIBRARY_PATH)
export PKG_CONFIG_PATH := $(NEONDIR)/lib/pkgconfig:$(NEONDIR)/lib/$(DEB_HOST_MULTIARCH)/pkgconfig:$(PKG_CONFIG_PATH)
export QT_PLUGIN_PATH := $(NEONDIR)/lib/qt4/plugins:$(NEONDIR)/lib/$(DEB_HOST_MULTIARCH)/qt4/plugins:$(QT_PLUGIN_PATH)
export QT_PLUGIN_PATH := $(NEONDIR)/lib/kde4/plugins:$(NEONDIR)/lib/$(DEB_HOST_MULTIARCH)/kde4/plugins:$(QT_PLUGIN_PATH)

# This has to be exported to make some magic below work.
export DH_OPTIONS

# Use verbose mode when building
export DH_VERBOSE=1

export DEB_BUILD_OPTIONS := noopt $(DEB_BUILD_OPTIONS)

ifeq ($(shell dpkg --compare-versions $(DPKG_VERSION) ge 1.16.1 && echo true),true)
# don't error out on warnings
export DEB_CFLAGS_MAINT_STRIP := $(DEB_CFLAGS_MAINT_STRIP) -Werror=format-security
export DEB_CXXFLAGS_MAINT_STRIP := $(DEB_CXXFLAGS_MAINT_STRIP) -Werror=format-security

# include default settings for dpkg
include /usr/share/dpkg/default.mk

else
# build with debug symbols and no compiler optimizations
export CFLAGS = -g -O0
export CXXFLAGS = -g -O0
export FFLAGS = -g -O0
endif

# enable quilt support by default unless it's explicitely disabled
ifeq ($(DN_NO_QUILT),)
dh_defaults := --with quilt $(dh_defaults)
endif

# use per-release series file if one exists
ifeq ($(shell [ -e debian/patches ] && ls debian/patches | grep series.$(BUILD_RELEASE)), series.$(BUILD_RELEASE))
export QUILT_SERIES=series.$(BUILD_RELEASE)
endif

# apport hook handling
# we put the link into the first package that's there, works for most cases
ifeq ($(HOOK_PACKAGE),)
	HOOK_PACKAGE := $(BINARY_NAME)
endif
REPLACES := $(shell $(SCRIPT_DIR)/get_control_field.pl Package $(HOOK_PACKAGE) Replaces)
ifneq ($(REPLACES),)
	REPLACES := $(REPLACES),
endif
